Class: Google::Cloud::Dataflow::V1beta3::CreateJobRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/dataflow/v1beta3/jobs.rb

Overview

Request to create a Cloud Dataflow job.

Instance Attribute Summary collapse

Instance Attribute Details

#job ⇒ ::Google::Cloud::Dataflow::V1beta3::Job

Returns The job to create.

Returns:



777
778
779
780
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 777

class CreateJobRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#location ⇒ ::String

Returns The [regional endpoint] (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints) that contains this job.

Returns:



777
778
779
780
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 777

class CreateJobRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project_id ⇒ ::String

Returns The ID of the Cloud Platform project that the job belongs to.

Returns:

  • (::String) —

    The ID of the Cloud Platform project that the job belongs to.



777
778
779
780
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 777

class CreateJobRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#replace_job_id ⇒ ::String

Returns Deprecated. This field is now in the Job message.

Returns:

  • (::String) —

    Deprecated. This field is now in the Job message.



777
778
779
780
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 777

class CreateJobRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#view ⇒ ::Google::Cloud::Dataflow::V1beta3::JobView

Returns The level of information requested in response.

Returns:



777
778
779
780
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 777

class CreateJobRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end