Class: Google::Cloud::Dataflow::V1beta3::DataSamplingConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/dataflow/v1beta3/environment.rb

Overview

Configuration options for sampling elements.

Defined Under Namespace

Modules: DataSamplingBehavior

Instance Attribute Summary collapse

Instance Attribute Details

#behaviors::Array<::Google::Cloud::Dataflow::V1beta3::DataSamplingConfig::DataSamplingBehavior>

Returns List of given sampling behaviors to enable. For example, specifying behaviors = [ALWAYS_ON] samples in-flight elements but does not sample exceptions. Can be used to specify multiple behaviors like, behaviors = [ALWAYS_ON, EXCEPTIONS] for specifying periodic sampling and exception sampling.

If DISABLED is in the list, then sampling will be disabled and ignore the other given behaviors.

Ordering does not matter.

Returns:

  • (::Array<::Google::Cloud::Dataflow::V1beta3::DataSamplingConfig::DataSamplingBehavior>)

    List of given sampling behaviors to enable. For example, specifying behaviors = [ALWAYS_ON] samples in-flight elements but does not sample exceptions. Can be used to specify multiple behaviors like, behaviors = [ALWAYS_ON, EXCEPTIONS] for specifying periodic sampling and exception sampling.

    If DISABLED is in the list, then sampling will be disabled and ignore the other given behaviors.

    Ordering does not matter.



513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'proto_docs/google/dataflow/v1beta3/environment.rb', line 513

class DataSamplingConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The following enum defines what to sample for a running job.
  module DataSamplingBehavior
    # If given, has no effect on sampling behavior. Used as an unknown or unset
    # sentinel value.
    DATA_SAMPLING_BEHAVIOR_UNSPECIFIED = 0

    # When given, disables element sampling. Has same behavior as not setting
    # the behavior.
    DISABLED = 1

    # When given, enables sampling in-flight from all PCollections.
    ALWAYS_ON = 2

    # When given, enables sampling input elements when a user-defined DoFn
    # causes an exception.
    EXCEPTIONS = 3
  end
end