Class: Google::Cloud::Dataflow::V1beta3::DisplayData
- Inherits:
-
Object
- Object
- Google::Cloud::Dataflow::V1beta3::DisplayData
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/dataflow/v1beta3/jobs.rb
Overview
Data provided with a pipeline or transform to provide descriptive info.
Instance Attribute Summary collapse
-
#bool_value ⇒ ::Boolean
Contains value if the data is of a boolean type.
-
#duration_value ⇒ ::Google::Protobuf::Duration
Contains value if the data is of duration type.
-
#float_value ⇒ ::Float
Contains value if the data is of float type.
-
#int64_value ⇒ ::Integer
Contains value if the data is of int64 type.
-
#java_class_value ⇒ ::String
Contains value if the data is of java class type.
-
#key ⇒ ::String
The key identifying the display data.
-
#label ⇒ ::String
An optional label to display in a dax UI for the element.
-
#namespace ⇒ ::String
The namespace for the key.
-
#short_str_value ⇒ ::String
A possible additional shorter value to display.
-
#str_value ⇒ ::String
Contains value if the data is of string type.
-
#timestamp_value ⇒ ::Google::Protobuf::Timestamp
Contains value if the data is of timestamp type.
-
#url ⇒ ::String
An optional full URL.
Instance Attribute Details
#bool_value ⇒ ::Boolean
665 666 667 668 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 665 class DisplayData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#duration_value ⇒ ::Google::Protobuf::Duration
665 666 667 668 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 665 class DisplayData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#float_value ⇒ ::Float
665 666 667 668 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 665 class DisplayData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#int64_value ⇒ ::Integer
665 666 667 668 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 665 class DisplayData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#java_class_value ⇒ ::String
665 666 667 668 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 665 class DisplayData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#key ⇒ ::String
665 666 667 668 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 665 class DisplayData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#label ⇒ ::String
665 666 667 668 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 665 class DisplayData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#namespace ⇒ ::String
665 666 667 668 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 665 class DisplayData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#short_str_value ⇒ ::String
665 666 667 668 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 665 class DisplayData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#str_value ⇒ ::String
665 666 667 668 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 665 class DisplayData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#timestamp_value ⇒ ::Google::Protobuf::Timestamp
665 666 667 668 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 665 class DisplayData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#url ⇒ ::String
665 666 667 668 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 665 class DisplayData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |