Class: Google::Cloud::Dataflow::V1beta3::FlexTemplateRuntimeEnvironment
- Inherits:
-
Object
- Object
- Google::Cloud::Dataflow::V1beta3::FlexTemplateRuntimeEnvironment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/dataflow/v1beta3/templates.rb
Overview
The environment values to be set at runtime for flex template.
Defined Under Namespace
Classes: AdditionalUserLabelsEntry
Instance Attribute Summary collapse
-
#additional_experiments ⇒ ::Array<::String>
Additional experiment flags for the job.
-
#additional_pipeline_options ⇒ ::Array<::String>
Optional.
-
#additional_user_labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Additional user labels to be specified for the job.
-
#autoscaling_algorithm ⇒ ::Google::Cloud::Dataflow::V1beta3::AutoscalingAlgorithm
The algorithm to use for autoscaling.
-
#disk_size_gb ⇒ ::Integer
Worker disk size, in gigabytes.
-
#dump_heap_on_oom ⇒ ::Boolean
If true, when processing time is spent almost entirely on garbage collection (GC), saves a heap dump before ending the thread or process.
-
#enable_launcher_vm_serial_port_logging ⇒ ::Boolean
If true serial port logging will be enabled for the launcher VM.
-
#enable_streaming_engine ⇒ ::Boolean
Whether to enable Streaming Engine for the job.
-
#flexrs_goal ⇒ ::Google::Cloud::Dataflow::V1beta3::FlexResourceSchedulingGoal
Set FlexRS goal for the job.
-
#ip_configuration ⇒ ::Google::Cloud::Dataflow::V1beta3::WorkerIPAddressConfiguration
Configuration for VM IPs.
-
#kms_key_name ⇒ ::String
Name for the Cloud KMS key for the job.
-
#launcher_machine_type ⇒ ::String
The machine type to use for launching the job.
-
#machine_type ⇒ ::String
The machine type to use for the job.
-
#max_workers ⇒ ::Integer
The maximum number of Google Compute Engine instances to be made available to your pipeline during execution, from 1 to 1000.
-
#network ⇒ ::String
Network to which VMs will be assigned.
-
#num_workers ⇒ ::Integer
The initial number of Google Compute Engine instances for the job.
-
#save_heap_dumps_to_gcs_path ⇒ ::String
Cloud Storage bucket (directory) to upload heap dumps to.
-
#sdk_container_image ⇒ ::String
Docker registry location of container image to use for the 'worker harness.
-
#service_account_email ⇒ ::String
The email address of the service account to run the job as.
-
#staging_location ⇒ ::String
The Cloud Storage path for staging local files.
-
#streaming_mode ⇒ ::Google::Cloud::Dataflow::V1beta3::StreamingMode
Optional.
-
#subnetwork ⇒ ::String
Subnetwork to which VMs will be assigned, if desired.
-
#temp_location ⇒ ::String
The Cloud Storage path to use for temporary files.
-
#worker_region ⇒ ::String
The Compute Engine region (https://cloud.google.com/compute/docs/regions-zones/regions-zones) in which worker processing should occur, e.g.
-
#worker_zone ⇒ ::String
The Compute Engine zone (https://cloud.google.com/compute/docs/regions-zones/regions-zones) in which worker processing should occur, e.g.
-
#zone ⇒ ::String
The Compute Engine availability zone for launching worker instances to run your pipeline.
Instance Attribute Details
#additional_experiments ⇒ ::Array<::String>
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#additional_pipeline_options ⇒ ::Array<::String>
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#additional_user_labels ⇒ ::Google::Protobuf::Map{::String => ::String}
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#autoscaling_algorithm ⇒ ::Google::Cloud::Dataflow::V1beta3::AutoscalingAlgorithm
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#disk_size_gb ⇒ ::Integer
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#dump_heap_on_oom ⇒ ::Boolean
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#enable_launcher_vm_serial_port_logging ⇒ ::Boolean
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#enable_streaming_engine ⇒ ::Boolean
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#flexrs_goal ⇒ ::Google::Cloud::Dataflow::V1beta3::FlexResourceSchedulingGoal
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#ip_configuration ⇒ ::Google::Cloud::Dataflow::V1beta3::WorkerIPAddressConfiguration
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kms_key_name ⇒ ::String
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#launcher_machine_type ⇒ ::String
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#machine_type ⇒ ::String
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#max_workers ⇒ ::Integer
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#network ⇒ ::String
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#num_workers ⇒ ::Integer
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#save_heap_dumps_to_gcs_path ⇒ ::String
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#sdk_container_image ⇒ ::String
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#service_account_email ⇒ ::String
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#staging_location ⇒ ::String
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#streaming_mode ⇒ ::Google::Cloud::Dataflow::V1beta3::StreamingMode
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#subnetwork ⇒ ::String
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#temp_location ⇒ ::String
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#worker_region ⇒ ::String
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#worker_zone ⇒ ::String
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#zone ⇒ ::String
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 255 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |