Class: Google::Cloud::Dataflow::V1beta3::GetJobExecutionDetailsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataflow::V1beta3::GetJobExecutionDetailsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/dataflow/v1beta3/metrics.rb
Overview
Request to get job execution details.
Instance Attribute Summary collapse
-
#job_id ⇒ ::String
The job to get execution details for.
-
#location ⇒ ::String
The regional endpoint that contains the job specified by job_id.
-
#page_size ⇒ ::Integer
If specified, determines the maximum number of stages to return.
-
#page_token ⇒ ::String
If supplied, this should be the value of next_page_token returned by an earlier call.
-
#project_id ⇒ ::String
A project id.
Instance Attribute Details
#job_id ⇒ ::String
Returns The job to get execution details for.
189 190 191 192 |
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 189 class GetJobExecutionDetailsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#location ⇒ ::String
Returns The regional endpoint that contains the job specified by job_id.
189 190 191 192 |
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 189 class GetJobExecutionDetailsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
If specified, determines the maximum number of stages to return. If unspecified, the service may choose an appropriate default, or may return an arbitrarily large number of results.
189 190 191 192 |
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 189 class GetJobExecutionDetailsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns If supplied, this should be the value of next_page_token returned by an earlier call. This will cause the next page of results to be returned.
189 190 191 192 |
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 189 class GetJobExecutionDetailsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project_id ⇒ ::String
Returns A project id.
189 190 191 192 |
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 189 class GetJobExecutionDetailsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |