Class: Google::Cloud::Dataflow::V1beta3::GetStageExecutionDetailsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/dataflow/v1beta3/metrics.rb

Overview

Request to get information about a particular execution stage of a job. Currently only tracked for Batch jobs.

Instance Attribute Summary collapse

Instance Attribute Details

#end_time::Google::Protobuf::Timestamp

Returns Upper time bound of work items to include, by start time.

Returns:



430
431
432
433
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 430

class GetStageExecutionDetailsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#job_id::String

Returns The job to get execution details for.

Returns:

  • (::String)

    The job to get execution details for.



430
431
432
433
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 430

class GetStageExecutionDetailsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#location::String

Returns The regional endpoint that contains the job specified by job_id.

Returns:



430
431
432
433
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 430

class GetStageExecutionDetailsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

If specified, determines the maximum number of work items to return. If unspecified, the service may choose an appropriate default, or may return an arbitrarily large number of results.

Returns:

  • (::Integer)

    If specified, determines the maximum number of work items to return. If unspecified, the service may choose an appropriate default, or may return an arbitrarily large number of results.



430
431
432
433
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 430

class GetStageExecutionDetailsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns If supplied, this should be the value of next_page_token returned by an earlier call. This will cause the next page of results to be returned.

Returns:

  • (::String)

    If supplied, this should be the value of next_page_token returned by an earlier call. This will cause the next page of results to be returned.



430
431
432
433
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 430

class GetStageExecutionDetailsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project_id::String

Returns A project id.

Returns:

  • (::String)

    A project id.



430
431
432
433
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 430

class GetStageExecutionDetailsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#stage_id::String

Returns The stage for which to fetch information.

Returns:

  • (::String)

    The stage for which to fetch information.



430
431
432
433
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 430

class GetStageExecutionDetailsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_time::Google::Protobuf::Timestamp

Returns Lower time bound of work items to include, by start time.

Returns:



430
431
432
433
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 430

class GetStageExecutionDetailsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end