Class: Google::Cloud::Dataflow::V1beta3::GetTemplateResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dataflow::V1beta3::GetTemplateResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/dataflow/v1beta3/templates.rb
Overview
The response to a GetTemplate request.
Defined Under Namespace
Modules: TemplateType
Instance Attribute Summary collapse
-
#metadata ⇒ ::Google::Cloud::Dataflow::V1beta3::TemplateMetadata
The template metadata describing the template name, available parameters, etc.
-
#runtime_metadata ⇒ ::Google::Cloud::Dataflow::V1beta3::RuntimeMetadata
Describes the runtime metadata with SDKInfo and available parameters.
-
#status ⇒ ::Google::Rpc::Status
The status of the get template request.
-
#template_type ⇒ ::Google::Cloud::Dataflow::V1beta3::GetTemplateResponse::TemplateType
Template Type.
Instance Attribute Details
#metadata ⇒ ::Google::Cloud::Dataflow::V1beta3::TemplateMetadata
Returns The template metadata describing the template name, available parameters, etc.
500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 500 class GetTemplateResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Template Type. module TemplateType # Unknown Template Type. UNKNOWN = 0 # Legacy Template. LEGACY = 1 # Flex Template. FLEX = 2 end end |
#runtime_metadata ⇒ ::Google::Cloud::Dataflow::V1beta3::RuntimeMetadata
Returns Describes the runtime metadata with SDKInfo and available parameters.
500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 500 class GetTemplateResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Template Type. module TemplateType # Unknown Template Type. UNKNOWN = 0 # Legacy Template. LEGACY = 1 # Flex Template. FLEX = 2 end end |
#status ⇒ ::Google::Rpc::Status
Returns The status of the get template request. Any problems with the request will be indicated in the error_details.
500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 500 class GetTemplateResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Template Type. module TemplateType # Unknown Template Type. UNKNOWN = 0 # Legacy Template. LEGACY = 1 # Flex Template. FLEX = 2 end end |
#template_type ⇒ ::Google::Cloud::Dataflow::V1beta3::GetTemplateResponse::TemplateType
Returns Template Type.
500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 500 class GetTemplateResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Template Type. module TemplateType # Unknown Template Type. UNKNOWN = 0 # Legacy Template. LEGACY = 1 # Flex Template. FLEX = 2 end end |