Module: Google::Cloud::Dataflow::V1beta3::Jobs

Defined in:
lib/google/cloud/dataflow/v1beta3/jobs.rb,
lib/google/cloud/dataflow/v1beta3/jobs/client.rb,
lib/google/cloud/dataflow/v1beta3/jobs/credentials.rb

Overview

Provides a method to create and modify Google Cloud Dataflow jobs. A Job is a multi-stage computation graph run by the Cloud Dataflow service.

To load this service and instantiate a client:

require "google/cloud/dataflow/v1beta3/jobs"
client = ::Google::Cloud::Dataflow::V1beta3::Jobs::Client.new

Defined Under Namespace

Classes: Client, Credentials