Class: Google::Cloud::Dataflow::V1beta3::LaunchTemplateRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/dataflow/v1beta3/templates.rb

Overview

A request to launch a template.

Instance Attribute Summary collapse

Instance Attribute Details

#dynamic_template ⇒ ::Google::Cloud::Dataflow::V1beta3::DynamicTemplateLaunchParams

Returns Params for launching a dynamic template.

Returns:



583
584
585
586
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 583

class LaunchTemplateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gcs_path ⇒ ::String

Returns A Cloud Storage path to the template from which to create the job. Must be valid Cloud Storage URL, beginning with 'gs://'.

Returns:

  • (::String) —

    A Cloud Storage path to the template from which to create the job. Must be valid Cloud Storage URL, beginning with 'gs://'.



583
584
585
586
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 583

class LaunchTemplateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#launch_parameters ⇒ ::Google::Cloud::Dataflow::V1beta3::LaunchTemplateParameters

Returns The parameters of the template to launch. This should be part of the body of the POST request.

Returns:



583
584
585
586
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 583

class LaunchTemplateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#location ⇒ ::String

Returns The [regional endpoint] (https://cloud.google.com/dataflow/docs/concepts/regional-endpoints) to which to direct the request.

Returns:



583
584
585
586
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 583

class LaunchTemplateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project_id ⇒ ::String

Returns Required. The ID of the Cloud Platform project that the job belongs to.

Returns:

  • (::String) —

    Required. The ID of the Cloud Platform project that the job belongs to.



583
584
585
586
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 583

class LaunchTemplateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only ⇒ ::Boolean

Returns If true, the request is validated but not actually executed. Defaults to false.

Returns:

  • (::Boolean) —

    If true, the request is validated but not actually executed. Defaults to false.



583
584
585
586
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 583

class LaunchTemplateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end