Class: Google::Cloud::Dataflow::V1beta3::ListJobMessagesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataflow::V1beta3::ListJobMessagesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/dataflow/v1beta3/messages.rb
Overview
Request to list job messages. Up to max_results messages will be returned in the time range specified starting with the oldest messages first. If no time range is specified the results with start with the oldest message.
Instance Attribute Summary collapse
-
#end_time ⇒ ::Google::Protobuf::Timestamp
Return only messages with timestamps < end_time.
-
#job_id ⇒ ::String
The job to get messages about.
-
#location ⇒ ::String
The regional endpoint that contains the job specified by job_id.
-
#minimum_importance ⇒ ::Google::Cloud::Dataflow::V1beta3::JobMessageImportance
Filter to only get messages with importance >= level.
-
#page_size ⇒ ::Integer
If specified, determines the maximum number of messages to return.
-
#page_token ⇒ ::String
If supplied, this should be the value of next_page_token returned by an earlier call.
-
#project_id ⇒ ::String
A project id.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
If specified, return only messages with timestamps >= start_time.
Instance Attribute Details
#end_time ⇒ ::Google::Protobuf::Timestamp
164 165 166 167 |
# File 'proto_docs/google/dataflow/v1beta3/messages.rb', line 164 class ListJobMessagesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#job_id ⇒ ::String
164 165 166 167 |
# File 'proto_docs/google/dataflow/v1beta3/messages.rb', line 164 class ListJobMessagesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#location ⇒ ::String
164 165 166 167 |
# File 'proto_docs/google/dataflow/v1beta3/messages.rb', line 164 class ListJobMessagesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#minimum_importance ⇒ ::Google::Cloud::Dataflow::V1beta3::JobMessageImportance
164 165 166 167 |
# File 'proto_docs/google/dataflow/v1beta3/messages.rb', line 164 class ListJobMessagesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
164 165 166 167 |
# File 'proto_docs/google/dataflow/v1beta3/messages.rb', line 164 class ListJobMessagesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
164 165 166 167 |
# File 'proto_docs/google/dataflow/v1beta3/messages.rb', line 164 class ListJobMessagesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project_id ⇒ ::String
164 165 166 167 |
# File 'proto_docs/google/dataflow/v1beta3/messages.rb', line 164 class ListJobMessagesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_time ⇒ ::Google::Protobuf::Timestamp
164 165 166 167 |
# File 'proto_docs/google/dataflow/v1beta3/messages.rb', line 164 class ListJobMessagesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |