Class: Google::Cloud::Dataflow::V1beta3::ListJobsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/dataflow/v1beta3/jobs.rb

Overview

Request to list Cloud Dataflow jobs.

Defined Under Namespace

Modules: Filter

Instance Attribute Summary collapse

Instance Attribute Details

#filter::Google::Cloud::Dataflow::V1beta3::ListJobsRequest::Filter



847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 847

class ListJobsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This field filters out and returns jobs in the specified job state. The
  # order of data returned is determined by the filter used, and is subject to
  # change.
  module Filter
    # The filter isn't specified, or is unknown. This returns all jobs ordered
    # on descending `JobUuid`.
    UNKNOWN = 0

    # Returns all running jobs first ordered on creation timestamp, then
    # returns all terminated jobs ordered on the termination timestamp.
    ALL = 1

    # Filters the jobs that have a terminated state, ordered on the
    # termination timestamp. Example terminated states: `JOB_STATE_STOPPED`,
    # `JOB_STATE_UPDATED`, `JOB_STATE_DRAINED`, etc.
    TERMINATED = 2

    # Filters the jobs that are running ordered on the creation timestamp.
    ACTIVE = 3
  end
end

#location::String



847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 847

class ListJobsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This field filters out and returns jobs in the specified job state. The
  # order of data returned is determined by the filter used, and is subject to
  # change.
  module Filter
    # The filter isn't specified, or is unknown. This returns all jobs ordered
    # on descending `JobUuid`.
    UNKNOWN = 0

    # Returns all running jobs first ordered on creation timestamp, then
    # returns all terminated jobs ordered on the termination timestamp.
    ALL = 1

    # Filters the jobs that have a terminated state, ordered on the
    # termination timestamp. Example terminated states: `JOB_STATE_STOPPED`,
    # `JOB_STATE_UPDATED`, `JOB_STATE_DRAINED`, etc.
    TERMINATED = 2

    # Filters the jobs that are running ordered on the creation timestamp.
    ACTIVE = 3
  end
end

#name::String



847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 847

class ListJobsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This field filters out and returns jobs in the specified job state. The
  # order of data returned is determined by the filter used, and is subject to
  # change.
  module Filter
    # The filter isn't specified, or is unknown. This returns all jobs ordered
    # on descending `JobUuid`.
    UNKNOWN = 0

    # Returns all running jobs first ordered on creation timestamp, then
    # returns all terminated jobs ordered on the termination timestamp.
    ALL = 1

    # Filters the jobs that have a terminated state, ordered on the
    # termination timestamp. Example terminated states: `JOB_STATE_STOPPED`,
    # `JOB_STATE_UPDATED`, `JOB_STATE_DRAINED`, etc.
    TERMINATED = 2

    # Filters the jobs that are running ordered on the creation timestamp.
    ACTIVE = 3
  end
end

#page_size::Integer



847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 847

class ListJobsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This field filters out and returns jobs in the specified job state. The
  # order of data returned is determined by the filter used, and is subject to
  # change.
  module Filter
    # The filter isn't specified, or is unknown. This returns all jobs ordered
    # on descending `JobUuid`.
    UNKNOWN = 0

    # Returns all running jobs first ordered on creation timestamp, then
    # returns all terminated jobs ordered on the termination timestamp.
    ALL = 1

    # Filters the jobs that have a terminated state, ordered on the
    # termination timestamp. Example terminated states: `JOB_STATE_STOPPED`,
    # `JOB_STATE_UPDATED`, `JOB_STATE_DRAINED`, etc.
    TERMINATED = 2

    # Filters the jobs that are running ordered on the creation timestamp.
    ACTIVE = 3
  end
end

#page_token::String



847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 847

class ListJobsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This field filters out and returns jobs in the specified job state. The
  # order of data returned is determined by the filter used, and is subject to
  # change.
  module Filter
    # The filter isn't specified, or is unknown. This returns all jobs ordered
    # on descending `JobUuid`.
    UNKNOWN = 0

    # Returns all running jobs first ordered on creation timestamp, then
    # returns all terminated jobs ordered on the termination timestamp.
    ALL = 1

    # Filters the jobs that have a terminated state, ordered on the
    # termination timestamp. Example terminated states: `JOB_STATE_STOPPED`,
    # `JOB_STATE_UPDATED`, `JOB_STATE_DRAINED`, etc.
    TERMINATED = 2

    # Filters the jobs that are running ordered on the creation timestamp.
    ACTIVE = 3
  end
end

#project_id::String



847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 847

class ListJobsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This field filters out and returns jobs in the specified job state. The
  # order of data returned is determined by the filter used, and is subject to
  # change.
  module Filter
    # The filter isn't specified, or is unknown. This returns all jobs ordered
    # on descending `JobUuid`.
    UNKNOWN = 0

    # Returns all running jobs first ordered on creation timestamp, then
    # returns all terminated jobs ordered on the termination timestamp.
    ALL = 1

    # Filters the jobs that have a terminated state, ordered on the
    # termination timestamp. Example terminated states: `JOB_STATE_STOPPED`,
    # `JOB_STATE_UPDATED`, `JOB_STATE_DRAINED`, etc.
    TERMINATED = 2

    # Filters the jobs that are running ordered on the creation timestamp.
    ACTIVE = 3
  end
end

#view::Google::Cloud::Dataflow::V1beta3::JobView

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Deprecated. ListJobs always returns summaries now. Use GetJob for other JobViews.



847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 847

class ListJobsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This field filters out and returns jobs in the specified job state. The
  # order of data returned is determined by the filter used, and is subject to
  # change.
  module Filter
    # The filter isn't specified, or is unknown. This returns all jobs ordered
    # on descending `JobUuid`.
    UNKNOWN = 0

    # Returns all running jobs first ordered on creation timestamp, then
    # returns all terminated jobs ordered on the termination timestamp.
    ALL = 1

    # Filters the jobs that have a terminated state, ordered on the
    # termination timestamp. Example terminated states: `JOB_STATE_STOPPED`,
    # `JOB_STATE_UPDATED`, `JOB_STATE_DRAINED`, etc.
    TERMINATED = 2

    # Filters the jobs that are running ordered on the creation timestamp.
    ACTIVE = 3
  end
end