Class: Google::Cloud::Dataflow::V1beta3::ListJobsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dataflow::V1beta3::ListJobsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/dataflow/v1beta3/jobs.rb
Overview
Response to a request to list Cloud Dataflow jobs in a project. This might be a partial response, depending on the page size in the ListJobsRequest. However, if the project does not have any jobs, an instance of ListJobsResponse is not returned and the requests's response body is empty {}.
Instance Attribute Summary collapse
-
#failed_location ⇒ ::Array<::Google::Cloud::Dataflow::V1beta3::FailedLocation>
Zero or more messages describing the regional endpoints that failed to respond.
-
#jobs ⇒ ::Array<::Google::Cloud::Dataflow::V1beta3::Job>
A subset of the requested job information.
-
#next_page_token ⇒ ::String
Set if there may be more results than fit in this response.
Instance Attribute Details
#failed_location ⇒ ::Array<::Google::Cloud::Dataflow::V1beta3::FailedLocation>
Returns Zero or more messages describing the regional endpoints that failed to respond.
915 916 917 918 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 915 class ListJobsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#jobs ⇒ ::Array<::Google::Cloud::Dataflow::V1beta3::Job>
Returns A subset of the requested job information.
915 916 917 918 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 915 class ListJobsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns Set if there may be more results than fit in this response.
915 916 917 918 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 915 class ListJobsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |