Class: Google::Cloud::Dataflow::V1beta3::Metrics::Client

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/dataflow/v1beta3/metrics/client.rb

Overview

Client for the Metrics service.

The Dataflow Metrics API lets you monitor the progress of Dataflow jobs.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new Metrics client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Dataflow::V1beta3::Metrics::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Dataflow::V1beta3::Metrics::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Metrics client.

Yield Parameters:



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/google/cloud/dataflow/v1beta3/metrics/client.rb', line 110

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/dataflow/v1beta3/metrics_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint == Client.configure.endpoint &&
                           !@config.endpoint.split(".").first.include?("-")
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @metrics_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::Dataflow::V1beta3::MetricsV1Beta3::Stub,
    credentials:  credentials,
    endpoint:     @config.endpoint,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors
  )
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the Metrics Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all Metrics clients
::Google::Cloud::Dataflow::V1beta3::Metrics::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/google/cloud/dataflow/v1beta3/metrics/client.rb', line 55

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Dataflow", "V1beta3"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.timeout = 60.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the Metrics Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



89
90
91
92
# File 'lib/google/cloud/dataflow/v1beta3/metrics/client.rb', line 89

def configure
  yield @config if block_given?
  @config
end

#get_job_execution_details(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::StageSummary> #get_job_execution_details(project_id: nil, job_id: nil, location: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::StageSummary>

Request detailed information about the execution status of the job.

EXPERIMENTAL. This API is subject to change or removal without notice.

Examples:

Basic example

require "google/cloud/dataflow/v1beta3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dataflow::V1beta3::Metrics::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dataflow::V1beta3::GetJobExecutionDetailsRequest.new

# Call the get_job_execution_details method.
result = client.get_job_execution_details request

# The returned object is of type Gapic::PagedEnumerable. You can
# iterate over all elements by calling #each, and the enumerable
# will lazily make API calls to fetch subsequent pages. Other
# methods are also available for managing paging directly.
result.each do |response|
  # Each element is of type ::Google::Cloud::Dataflow::V1beta3::StageSummary.
  p response
end

Overloads:

  • #get_job_execution_details(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::StageSummary>

    Pass arguments to get_job_execution_details via a request object, either of type GetJobExecutionDetailsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataflow::V1beta3::GetJobExecutionDetailsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_job_execution_details(project_id: nil, job_id: nil, location: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::StageSummary>

    Pass arguments to get_job_execution_details via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      A project id.

    • job_id (::String) (defaults to: nil)

      The job to get execution details for.

    • location (::String) (defaults to: nil)

      The regional endpoint that contains the job specified by job_id.

    • page_size (::Integer) (defaults to: nil)

      If specified, determines the maximum number of stages to return. If unspecified, the service may choose an appropriate default, or may return an arbitrarily large number of results.

    • page_token (::String) (defaults to: nil)

      If supplied, this should be the value of next_page_token returned by an earlier call. This will cause the next page of results to be returned.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/google/cloud/dataflow/v1beta3/metrics/client.rb', line 317

def get_job_execution_details request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::GetJobExecutionDetailsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_job_execution_details..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.project_id
    header_params["project_id"] = request.project_id
  end
  if request.location
    header_params["location"] = request.location
  end
  if request.job_id
    header_params["job_id"] = request.job_id
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_job_execution_details.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_job_execution_details.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @metrics_stub.call_rpc :get_job_execution_details, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @metrics_stub, :get_job_execution_details, request, response, operation, options
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_job_metrics(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::JobMetrics #get_job_metrics(project_id: nil, job_id: nil, start_time: nil, location: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::JobMetrics

Request the job status.

To request the status of a job, we recommend using projects.locations.jobs.getMetrics with a regional endpoint. Using projects.jobs.getMetrics is not recommended, as you can only request the status of jobs that are running in us-central1.

Examples:

Basic example

require "google/cloud/dataflow/v1beta3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dataflow::V1beta3::Metrics::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dataflow::V1beta3::GetJobMetricsRequest.new

# Call the get_job_metrics method.
result = client.get_job_metrics request

# The returned object is of type Google::Cloud::Dataflow::V1beta3::JobMetrics.
p result

Overloads:

  • #get_job_metrics(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::JobMetrics

    Pass arguments to get_job_metrics via a request object, either of type GetJobMetricsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataflow::V1beta3::GetJobMetricsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_job_metrics(project_id: nil, job_id: nil, start_time: nil, location: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::JobMetrics

    Pass arguments to get_job_metrics via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      A project id.

    • job_id (::String) (defaults to: nil)

      The job to get metrics for.

    • start_time (::Google::Protobuf::Timestamp, ::Hash) (defaults to: nil)

      Return only metric data that has changed since this time. Default is to return all information about all metrics for the job.

    • location (::String) (defaults to: nil)

      The regional endpoint that contains the job specified by job_id.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/google/cloud/dataflow/v1beta3/metrics/client.rb', line 207

def get_job_metrics request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::GetJobMetricsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_job_metrics..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.project_id
    header_params["project_id"] = request.project_id
  end
  if request.job_id
    header_params["job_id"] = request.job_id
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_job_metrics.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_job_metrics.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @metrics_stub.call_rpc :get_job_metrics, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_stage_execution_details(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::WorkerDetails> #get_stage_execution_details(project_id: nil, job_id: nil, location: nil, stage_id: nil, page_size: nil, page_token: nil, start_time: nil, end_time: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::WorkerDetails>

Request detailed information about the execution status of a stage of the job.

EXPERIMENTAL. This API is subject to change or removal without notice.

Examples:

Basic example

require "google/cloud/dataflow/v1beta3"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Dataflow::V1beta3::Metrics::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Dataflow::V1beta3::GetStageExecutionDetailsRequest.new

# Call the get_stage_execution_details method.
result = client.get_stage_execution_details request

# The returned object is of type Gapic::PagedEnumerable. You can
# iterate over all elements by calling #each, and the enumerable
# will lazily make API calls to fetch subsequent pages. Other
# methods are also available for managing paging directly.
result.each do |response|
  # Each element is of type ::Google::Cloud::Dataflow::V1beta3::WorkerDetails.
  p response
end

Overloads:

  • #get_stage_execution_details(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::WorkerDetails>

    Pass arguments to get_stage_execution_details via a request object, either of type GetStageExecutionDetailsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataflow::V1beta3::GetStageExecutionDetailsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_stage_execution_details(project_id: nil, job_id: nil, location: nil, stage_id: nil, page_size: nil, page_token: nil, start_time: nil, end_time: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::WorkerDetails>

    Pass arguments to get_stage_execution_details via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil)

      A project id.

    • job_id (::String) (defaults to: nil)

      The job to get execution details for.

    • location (::String) (defaults to: nil)

      The regional endpoint that contains the job specified by job_id.

    • stage_id (::String) (defaults to: nil)

      The stage for which to fetch information.

    • page_size (::Integer) (defaults to: nil)

      If specified, determines the maximum number of work items to return. If unspecified, the service may choose an appropriate default, or may return an arbitrarily large number of results.

    • page_token (::String) (defaults to: nil)

      If supplied, this should be the value of next_page_token returned by an earlier call. This will cause the next page of results to be returned.

    • start_time (::Google::Protobuf::Timestamp, ::Hash) (defaults to: nil)

      Lower time bound of work items to include, by start time.

    • end_time (::Google::Protobuf::Timestamp, ::Hash) (defaults to: nil)

      Upper time bound of work items to include, by start time.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
# File 'lib/google/cloud/dataflow/v1beta3/metrics/client.rb', line 438

def get_stage_execution_details request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::GetStageExecutionDetailsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_stage_execution_details..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.project_id
    header_params["project_id"] = request.project_id
  end
  if request.location
    header_params["location"] = request.location
  end
  if request.job_id
    header_params["job_id"] = request.job_id
  end
  if request.stage_id
    header_params["stage_id"] = request.stage_id
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_stage_execution_details.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_stage_execution_details.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @metrics_stub.call_rpc :get_stage_execution_details, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @metrics_stub, :get_stage_execution_details, request, response, operation, options
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end