Module: Google::Cloud::Dataflow::V1beta3::ParameterType
- Defined in:
- proto_docs/google/dataflow/v1beta3/templates.rb
Overview
ParameterType specifies what kind of input we need for this parameter.
Constant Summary collapse
- DEFAULT =
Default input type.
0- TEXT =
The parameter specifies generic text input.
1- GCS_READ_BUCKET =
The parameter specifies a Cloud Storage Bucket to read from.
2- GCS_WRITE_BUCKET =
The parameter specifies a Cloud Storage Bucket to write to.
3- GCS_READ_FILE =
The parameter specifies a Cloud Storage file path to read from.
4- GCS_WRITE_FILE =
The parameter specifies a Cloud Storage file path to write to.
5- GCS_READ_FOLDER =
The parameter specifies a Cloud Storage folder path to read from.
6- GCS_WRITE_FOLDER =
The parameter specifies a Cloud Storage folder to write to.
7- PUBSUB_TOPIC =
The parameter specifies a Pub/Sub Topic.
8- PUBSUB_SUBSCRIPTION =
The parameter specifies a Pub/Sub Subscription.
9