Class: Google::Cloud::Dataflow::V1beta3::PipelineDescription

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/dataflow/v1beta3/jobs.rb

Overview

A descriptive representation of submitted pipeline as well as the executed form. This data is provided by the Dataflow service for ease of visualizing the pipeline and interpreting Dataflow provided metrics.

Instance Attribute Summary collapse

Instance Attribute Details

#display_data::Array<::Google::Cloud::Dataflow::V1beta3::DisplayData>

Returns Pipeline level display data.

Returns:



504
505
506
507
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 504

class PipelineDescription
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#execution_pipeline_stage::Array<::Google::Cloud::Dataflow::V1beta3::ExecutionStageSummary>

Returns Description of each stage of execution of the pipeline.

Returns:



504
505
506
507
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 504

class PipelineDescription
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#original_pipeline_transform::Array<::Google::Cloud::Dataflow::V1beta3::TransformSummary>

Returns Description of each transform in the pipeline and collections between them.

Returns:



504
505
506
507
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 504

class PipelineDescription
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#step_names_hash::String

Returns A hash value of the submitted pipeline portable graph step names if exists.

Returns:

  • (::String)

    A hash value of the submitted pipeline portable graph step names if exists.



504
505
506
507
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 504

class PipelineDescription
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end