Class: Google::Cloud::Dataflow::V1beta3::PubsubLocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/dataflow/v1beta3/streaming.rb

Overview

Identifies a pubsub location to use for transferring data into or out of a streaming Dataflow job.

Instance Attribute Summary collapse

Instance Attribute Details

#drop_late_data ⇒ ::Boolean

Returns Indicates whether the pipeline allows late-arriving data.

Returns:

  • (::Boolean) —

    Indicates whether the pipeline allows late-arriving data.



86
87
88
89
# File 'proto_docs/google/dataflow/v1beta3/streaming.rb', line 86

class PubsubLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#dynamic_destinations ⇒ ::Boolean

Returns If true, then this location represents dynamic topics.

Returns:

  • (::Boolean) —

    If true, then this location represents dynamic topics.



86
87
88
89
# File 'proto_docs/google/dataflow/v1beta3/streaming.rb', line 86

class PubsubLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#id_label ⇒ ::String

Returns If set, contains a pubsub label from which to extract record ids. If left empty, record deduplication will be strictly best effort.

Returns:

  • (::String) —

    If set, contains a pubsub label from which to extract record ids. If left empty, record deduplication will be strictly best effort.



86
87
88
89
# File 'proto_docs/google/dataflow/v1beta3/streaming.rb', line 86

class PubsubLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#subscription ⇒ ::String

Returns A pubsub subscription, in the form of "pubsub.googleapis.com/subscriptions//".

Returns:

  • (::String) —

    A pubsub subscription, in the form of "pubsub.googleapis.com/subscriptions//"



86
87
88
89
# File 'proto_docs/google/dataflow/v1beta3/streaming.rb', line 86

class PubsubLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#timestamp_label ⇒ ::String

Returns If set, contains a pubsub label from which to extract record timestamps. If left empty, record timestamps will be generated upon arrival.

Returns:

  • (::String) —

    If set, contains a pubsub label from which to extract record timestamps. If left empty, record timestamps will be generated upon arrival.



86
87
88
89
# File 'proto_docs/google/dataflow/v1beta3/streaming.rb', line 86

class PubsubLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#topic ⇒ ::String

Returns A pubsub topic, in the form of "pubsub.googleapis.com/topics//".

Returns:

  • (::String) —

    A pubsub topic, in the form of "pubsub.googleapis.com/topics//"



86
87
88
89
# File 'proto_docs/google/dataflow/v1beta3/streaming.rb', line 86

class PubsubLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tracking_subscription ⇒ ::String

Returns If set, specifies the pubsub subscription that will be used for tracking custom time timestamps for watermark estimation.

Returns:

  • (::String) —

    If set, specifies the pubsub subscription that will be used for tracking custom time timestamps for watermark estimation.



86
87
88
89
# File 'proto_docs/google/dataflow/v1beta3/streaming.rb', line 86

class PubsubLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#with_attributes ⇒ ::Boolean

Returns If true, then the client has requested to get pubsub attributes.

Returns:

  • (::Boolean) —

    If true, then the client has requested to get pubsub attributes.



86
87
88
89
# File 'proto_docs/google/dataflow/v1beta3/streaming.rb', line 86

class PubsubLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end