Class: Google::Cloud::Dataflow::V1beta3::SdkHarnessContainerImage
- Inherits:
-
Object
- Object
- Google::Cloud::Dataflow::V1beta3::SdkHarnessContainerImage
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/dataflow/v1beta3/environment.rb
Overview
Defines an SDK harness container for executing Dataflow pipelines.
Instance Attribute Summary collapse
-
#capabilities ⇒ ::Array<::String>
The set of capabilities enumerated in the above Environment proto.
-
#container_image ⇒ ::String
A docker container image that resides in Google Container Registry.
-
#environment_id ⇒ ::String
Environment ID for the Beam runner API proto Environment that corresponds to the current SDK Harness.
-
#use_single_core_per_container ⇒ ::Boolean
If true, recommends the Dataflow service to use only one core per SDK container instance with this image.
Instance Attribute Details
#capabilities ⇒ ::Array<::String>
Returns The set of capabilities enumerated in the above Environment proto. See also beam_runner_api.proto.
358 359 360 361 |
# File 'proto_docs/google/dataflow/v1beta3/environment.rb', line 358 class SdkHarnessContainerImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#container_image ⇒ ::String
Returns A docker container image that resides in Google Container Registry.
358 359 360 361 |
# File 'proto_docs/google/dataflow/v1beta3/environment.rb', line 358 class SdkHarnessContainerImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#environment_id ⇒ ::String
Returns Environment ID for the Beam runner API proto Environment that corresponds to the current SDK Harness.
358 359 360 361 |
# File 'proto_docs/google/dataflow/v1beta3/environment.rb', line 358 class SdkHarnessContainerImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#use_single_core_per_container ⇒ ::Boolean
Returns If true, recommends the Dataflow service to use only one core per SDK container instance with this image. If false (or unset) recommends using more than one core per SDK container instance with this image for efficiency. Note that Dataflow service may choose to override this property if needed.
358 359 360 361 |
# File 'proto_docs/google/dataflow/v1beta3/environment.rb', line 358 class SdkHarnessContainerImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |