Class: Google::Cloud::Dataflow::V1beta3::ServiceResources

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/dataflow/v1beta3/jobs.rb

Overview

Resources used by the Dataflow Service to run the job.

Instance Attribute Summary collapse

Instance Attribute Details

#zones::Array<::String> (readonly)

Returns Output only. List of Cloud Zones being used by the Dataflow Service for this job. Example: us-central1-c.

Returns:

  • (::Array<::String>)

    Output only. List of Cloud Zones being used by the Dataflow Service for this job. Example: us-central1-c



224
225
226
227
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 224

class ServiceResources
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end