Class: Google::Cloud::Dataflow::V1beta3::SnapshotJobRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/dataflow/v1beta3/jobs.rb

Overview

Request to create a snapshot of a job.

Instance Attribute Summary collapse

Instance Attribute Details

#description ⇒ ::String

Returns User specified description of the snapshot. Maybe empty.

Returns:

  • (::String) —

    User specified description of the snapshot. Maybe empty.



939
940
941
942
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 939

class SnapshotJobRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#job_id ⇒ ::String

Returns The job to be snapshotted.

Returns:

  • (::String) —

    The job to be snapshotted.



939
940
941
942
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 939

class SnapshotJobRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#location ⇒ ::String

Returns The location that contains this job.

Returns:

  • (::String) —

    The location that contains this job.



939
940
941
942
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 939

class SnapshotJobRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project_id ⇒ ::String

Returns The project which owns the job to be snapshotted.

Returns:

  • (::String) —

    The project which owns the job to be snapshotted.



939
940
941
942
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 939

class SnapshotJobRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#snapshot_sources ⇒ ::Boolean

Returns If true, perform snapshots for sources which support this.

Returns:

  • (::Boolean) —

    If true, perform snapshots for sources which support this.



939
940
941
942
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 939

class SnapshotJobRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ttl ⇒ ::Google::Protobuf::Duration

Returns TTL for the snapshot.

Returns:



939
940
941
942
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 939

class SnapshotJobRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end