Class: Google::Cloud::Dataflow::V1beta3::Snapshots::Client

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/dataflow/v1beta3/snapshots/client.rb

Overview

Client for the Snapshots service.

Provides methods to manage snapshots of Google Cloud Dataflow jobs.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new Snapshots client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Dataflow::V1beta3::Snapshots::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Dataflow::V1beta3::Snapshots::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config) —

    Configure the Snapshots client.

Yield Parameters:



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/google/cloud/dataflow/v1beta3/snapshots/client.rb', line 109

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/dataflow/v1beta3/snapshots_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint == Client.configure.endpoint &&
                           !@config.endpoint.split(".").first.include?("-")
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @snapshots_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::Dataflow::V1beta3::SnapshotsV1Beta3::Stub,
    credentials:  credentials,
    endpoint:     @config.endpoint,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors
  )
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the Snapshots Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all Snapshots clients
::Google::Cloud::Dataflow::V1beta3::Snapshots::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config) —

    Configure the Client client.

Yield Parameters:

Returns:



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/google/cloud/dataflow/v1beta3/snapshots/client.rb', line 54

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Dataflow", "V1beta3"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.timeout = 60.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the Snapshots Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config) —

    Configure the Client client.

Yield Parameters:

Returns:



88
89
90
91
# File 'lib/google/cloud/dataflow/v1beta3/snapshots/client.rb', line 88

def configure
  yield @config if block_given?
  @config
end

#delete_snapshot(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::DeleteSnapshotResponse #delete_snapshot(project_id: nil, snapshot_id: nil, location: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::DeleteSnapshotResponse

Deletes a snapshot.

Overloads:

  • #delete_snapshot(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::DeleteSnapshotResponse

    Pass arguments to delete_snapshot via a request object, either of type DeleteSnapshotRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataflow::V1beta3::DeleteSnapshotRequest, ::Hash) —

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil) —

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #delete_snapshot(project_id: nil, snapshot_id: nil, location: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::DeleteSnapshotResponse

    Pass arguments to delete_snapshot via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil) —

      The ID of the Cloud Platform project that the snapshot belongs to.

    • snapshot_id (::String) (defaults to: nil) —

      The ID of the snapshot.

    • location (::String) (defaults to: nil) —

      The location that contains this snapshot.

Yields:

  • (response, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error) —

    if the RPC is aborted.



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/google/cloud/dataflow/v1beta3/snapshots/client.rb', line 246

def delete_snapshot request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::DeleteSnapshotRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_snapshot..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.delete_snapshot.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_snapshot.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @snapshots_stub.call_rpc :delete_snapshot, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_snapshot(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Snapshot #get_snapshot(project_id: nil, snapshot_id: nil, location: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Snapshot

Gets information about a snapshot.

Overloads:

  • #get_snapshot(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Snapshot

    Pass arguments to get_snapshot via a request object, either of type GetSnapshotRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataflow::V1beta3::GetSnapshotRequest, ::Hash) —

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil) —

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_snapshot(project_id: nil, snapshot_id: nil, location: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Snapshot

    Pass arguments to get_snapshot via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil) —

      The ID of the Cloud Platform project that the snapshot belongs to.

    • snapshot_id (::String) (defaults to: nil) —

      The ID of the snapshot.

    • location (::String) (defaults to: nil) —

      The location that contains this snapshot.

Yields:

  • (response, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error) —

    if the RPC is aborted.



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/google/cloud/dataflow/v1beta3/snapshots/client.rb', line 180

def get_snapshot request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::GetSnapshotRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_snapshot..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_snapshot.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_snapshot.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @snapshots_stub.call_rpc :get_snapshot, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_snapshots(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::ListSnapshotsResponse #list_snapshots(project_id: nil, job_id: nil, location: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::ListSnapshotsResponse

Lists snapshots.

Overloads:

  • #list_snapshots(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::ListSnapshotsResponse

    Pass arguments to list_snapshots via a request object, either of type ListSnapshotsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataflow::V1beta3::ListSnapshotsRequest, ::Hash) —

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil) —

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_snapshots(project_id: nil, job_id: nil, location: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::ListSnapshotsResponse

    Pass arguments to list_snapshots via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil) —

      The project ID to list snapshots for.

    • job_id (::String) (defaults to: nil) —

      If specified, list snapshots created from this job.

    • location (::String) (defaults to: nil) —

      The location to list snapshots in.

Yields:

  • (response, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error) —

    if the RPC is aborted.



312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/google/cloud/dataflow/v1beta3/snapshots/client.rb', line 312

def list_snapshots request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::ListSnapshotsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_snapshots..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_snapshots.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_snapshots.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @snapshots_stub.call_rpc :list_snapshots, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end