Class: Google::Cloud::Dataflow::V1beta3::StageSummary

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/dataflow/v1beta3/metrics.rb

Overview

Information about a particular execution stage of a job.

Instance Attribute Summary collapse

Instance Attribute Details

#end_time::Google::Protobuf::Timestamp

Returns End time of this stage.

If the work item is completed, this is the actual end time of the stage. Otherwise, it is the predicted end time.

Returns:

  • (::Google::Protobuf::Timestamp)

    End time of this stage.

    If the work item is completed, this is the actual end time of the stage. Otherwise, it is the predicted end time.



379
380
381
382
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 379

class StageSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#metrics::Array<::Google::Cloud::Dataflow::V1beta3::MetricUpdate>

Returns Metrics for this stage.

Returns:



379
380
381
382
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 379

class StageSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#progress::Google::Cloud::Dataflow::V1beta3::ProgressTimeseries

Returns Progress for this stage. Only applicable to Batch jobs.

Returns:



379
380
381
382
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 379

class StageSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#stage_id::String

Returns ID of this stage.

Returns:

  • (::String)

    ID of this stage



379
380
381
382
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 379

class StageSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_time::Google::Protobuf::Timestamp

Returns Start time of this stage.

Returns:



379
380
381
382
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 379

class StageSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#state::Google::Cloud::Dataflow::V1beta3::ExecutionState

Returns State of this stage.

Returns:



379
380
381
382
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 379

class StageSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#straggler_summary::Google::Cloud::Dataflow::V1beta3::StragglerSummary

Returns Straggler summary for this stage.

Returns:



379
380
381
382
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 379

class StageSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end