Class: Google::Cloud::Dataflow::V1beta3::FlexTemplateRuntimeEnvironment
- Inherits:
-
Object
- Object
- Google::Cloud::Dataflow::V1beta3::FlexTemplateRuntimeEnvironment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/dataflow/v1beta3/templates.rb
Overview
The environment values to be set at runtime for flex template.
Defined Under Namespace
Classes: AdditionalUserLabelsEntry
Instance Attribute Summary collapse
-
#additional_experiments ⇒ ::Array<::String>
Additional experiment flags for the job.
-
#additional_user_labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Additional user labels to be specified for the job.
-
#enable_streaming_engine ⇒ ::Boolean
Whether to enable Streaming Engine for the job.
-
#flexrs_goal ⇒ ::Google::Cloud::Dataflow::V1beta3::FlexResourceSchedulingGoal
Set FlexRS goal for the job.
-
#ip_configuration ⇒ ::Google::Cloud::Dataflow::V1beta3::WorkerIPAddressConfiguration
Configuration for VM IPs.
-
#kms_key_name ⇒ ::String
Name for the Cloud KMS key for the job.
-
#machine_type ⇒ ::String
The machine type to use for the job.
-
#max_workers ⇒ ::Integer
The maximum number of Google Compute Engine instances to be made available to your pipeline during execution, from 1 to 1000.
-
#network ⇒ ::String
Network to which VMs will be assigned.
-
#num_workers ⇒ ::Integer
The initial number of Google Compute Engine instances for the job.
-
#sdk_container_image ⇒ ::String
Docker registry location of container image to use for the 'worker harness.
-
#service_account_email ⇒ ::String
The email address of the service account to run the job as.
-
#staging_location ⇒ ::String
The Cloud Storage path for staging local files.
-
#subnetwork ⇒ ::String
Subnetwork to which VMs will be assigned, if desired.
-
#temp_location ⇒ ::String
The Cloud Storage path to use for temporary files.
-
#worker_region ⇒ ::String
The Compute Engine region (https://cloud.google.com/compute/docs/regions-zones/regions-zones) in which worker processing should occur, e.g.
-
#worker_zone ⇒ ::String
The Compute Engine zone (https://cloud.google.com/compute/docs/regions-zones/regions-zones) in which worker processing should occur, e.g.
-
#zone ⇒ ::String
The Compute Engine availability zone for launching worker instances to run your pipeline.
Instance Attribute Details
#additional_experiments ⇒ ::Array<::String>
Returns Additional experiment flags for the job.
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#additional_user_labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Additional user labels to be specified for the job. Keys and values must follow the restrictions specified in the labeling restrictions page. An object containing a list of "key": value pairs. Example: { "name": "wrench", "mass": "1kg", "count": "3" }.
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#enable_streaming_engine ⇒ ::Boolean
Returns Whether to enable Streaming Engine for the job.
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#flexrs_goal ⇒ ::Google::Cloud::Dataflow::V1beta3::FlexResourceSchedulingGoal
Returns Set FlexRS goal for the job. https://cloud.google.com/dataflow/docs/guides/flexrs.
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#ip_configuration ⇒ ::Google::Cloud::Dataflow::V1beta3::WorkerIPAddressConfiguration
Returns Configuration for VM IPs.
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kms_key_name ⇒ ::String
Returns Name for the Cloud KMS key for the job.
Key format is:
projects/
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#machine_type ⇒ ::String
Returns The machine type to use for the job. Defaults to the value from the template if not specified.
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#max_workers ⇒ ::Integer
Returns The maximum number of Google Compute Engine instances to be made available to your pipeline during execution, from 1 to 1000.
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#network ⇒ ::String
Returns Network to which VMs will be assigned. If empty or unspecified, the service will use the network "default".
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#num_workers ⇒ ::Integer
Returns The initial number of Google Compute Engine instances for the job.
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#sdk_container_image ⇒ ::String
Returns Docker registry location of container image to use for the 'worker harness. Default is the container for the version of the SDK. Note this field is only valid for portable pipelines.
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#service_account_email ⇒ ::String
Returns The email address of the service account to run the job as.
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#staging_location ⇒ ::String
Returns The Cloud Storage path for staging local files.
Must be a valid Cloud Storage URL, beginning with gs://.
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#subnetwork ⇒ ::String
Returns Subnetwork to which VMs will be assigned, if desired. You can specify a subnetwork using either a complete URL or an abbreviated path. Expected to be of the form "https://www.googleapis.com/compute/v1/projects/HOST_PROJECT_ID/regions/REGION/subnetworks/SUBNETWORK" or "regions/REGION/subnetworks/SUBNETWORK". If the subnetwork is located in a Shared VPC network, you must use the complete URL.
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#temp_location ⇒ ::String
Returns The Cloud Storage path to use for temporary files.
Must be a valid Cloud Storage URL, beginning with gs://.
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#worker_region ⇒ ::String
Returns The Compute Engine region (https://cloud.google.com/compute/docs/regions-zones/regions-zones) in which worker processing should occur, e.g. "us-west1". Mutually exclusive with worker_zone. If neither worker_region nor worker_zone is specified, default to the control plane's region.
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#worker_zone ⇒ ::String
Returns The Compute Engine zone
(https://cloud.google.com/compute/docs/regions-zones/regions-zones) in
which worker processing should occur, e.g. "us-west1-a". Mutually exclusive
with worker_region. If neither worker_region nor worker_zone is specified,
a zone in the control plane's region is chosen based on available capacity.
If both worker_zone and zone are set, worker_zone takes precedence.
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#zone ⇒ ::String
Returns The Compute Engine availability zone for launching worker instances to run your pipeline. In the future, worker_zone will take precedence.
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'proto_docs/google/dataflow/v1beta3/templates.rb', line 204 class FlexTemplateRuntimeEnvironment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalUserLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |