Class: Google::Cloud::Dataflow::V1beta3::GetJobExecutionDetailsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataflow::V1beta3::GetJobExecutionDetailsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/dataflow/v1beta3/metrics.rb
Overview
Request to get job execution details.
Instance Attribute Summary collapse
-
#job_id ⇒ ::String
The job to get execution details for.
-
#location ⇒ ::String
The regional endpoint that contains the job specified by job_id.
-
#page_size ⇒ ::Integer
If specified, determines the maximum number of stages to return.
-
#page_token ⇒ ::String
If supplied, this should be the value of next_page_token returned by an earlier call.
-
#project_id ⇒ ::String
A project id.
Instance Attribute Details
#job_id ⇒ ::String
178 179 180 181 |
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 178 class GetJobExecutionDetailsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#location ⇒ ::String
178 179 180 181 |
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 178 class GetJobExecutionDetailsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
178 179 180 181 |
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 178 class GetJobExecutionDetailsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
178 179 180 181 |
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 178 class GetJobExecutionDetailsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project_id ⇒ ::String
178 179 180 181 |
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 178 class GetJobExecutionDetailsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |