Class: Google::Cloud::Dataflow::V1beta3::Jobs::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Dataflow::V1beta3::Jobs::Client
- Defined in:
- lib/google/cloud/dataflow/v1beta3/jobs/client.rb
Overview
Client for the Jobs service.
Provides a method to create and modify Google Cloud Dataflow jobs. A Job is a multi-stage computation graph run by the Cloud Dataflow service.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the Jobs Client class.
Instance Method Summary collapse
-
#aggregated_list_jobs(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::Job>
List the jobs of a project across all regions.
-
#check_active_jobs(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Dataflow::V1beta3::CheckActiveJobsResponse
Check for existence of active jobs in the given project across all regions.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the Jobs Client instance.
-
#create_job(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Dataflow::V1beta3::Job
Creates a Cloud Dataflow job.
-
#get_job(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Dataflow::V1beta3::Job
Gets the state of the specified Cloud Dataflow job.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new Jobs client object.
-
#list_jobs(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::Job>
List the jobs of a project.
-
#snapshot_job(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Dataflow::V1beta3::Snapshot
Snapshot the state of a streaming job.
-
#update_job(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Dataflow::V1beta3::Job
Updates the state of an existing Cloud Dataflow job.
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new Jobs client object.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 110 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/dataflow/v1beta3/jobs_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint == Client.configure.endpoint && !@config.endpoint.split(".").first.include?("-") credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @jobs_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::Dataflow::V1beta3::JobsV1Beta3::Stub, credentials: credentials, endpoint: @config.endpoint, channel_args: @config.channel_args, interceptors: @config.interceptors ) end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the Jobs Client class.
See Configuration for a description of the configuration fields.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 55 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Dataflow", "V1beta3"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.timeout = 60.0 default_config end yield @configure if block_given? @configure end |
Instance Method Details
#aggregated_list_jobs(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::Job> #aggregated_list_jobs(filter: nil, project_id: nil, view: nil, page_size: nil, page_token: nil, location: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::Job>
List the jobs of a project across all regions.
635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 |
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 635 def aggregated_list_jobs request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::ListJobsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.aggregated_list_jobs..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.project_id header_params["project_id"] = request.project_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.aggregated_list_jobs.timeout, metadata: , retry_policy: @config.rpcs.aggregated_list_jobs.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @jobs_stub.call_rpc :aggregated_list_jobs, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @jobs_stub, :aggregated_list_jobs, request, response, operation, yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#check_active_jobs(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::CheckActiveJobsResponse #check_active_jobs(project_id: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::CheckActiveJobsResponse
Check for existence of active jobs in the given project across all regions.
721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 |
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 721 def check_active_jobs request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::CheckActiveJobsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.check_active_jobs..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.check_active_jobs.timeout, metadata: , retry_policy: @config.rpcs.check_active_jobs.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @jobs_stub.call_rpc :check_active_jobs, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the Jobs Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
89 90 91 92 |
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 89 def configure yield @config if block_given? @config end |
#create_job(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job #create_job(project_id: nil, job: nil, view: nil, replace_job_id: nil, location: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job
Creates a Cloud Dataflow job.
To create a job, we recommend using projects.locations.jobs.create with a
regional endpoint. Using
projects.jobs.create is not recommended, as your job will always start
in us-central1.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 208 def create_job request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::CreateJobRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_job..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.project_id header_params["project_id"] = request.project_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_job.timeout, metadata: , retry_policy: @config.rpcs.create_job.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @jobs_stub.call_rpc :create_job, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_job(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job #get_job(project_id: nil, job_id: nil, view: nil, location: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job
Gets the state of the specified Cloud Dataflow job.
To get the state of a job, we recommend using projects.locations.jobs.get
with a regional endpoint. Using
projects.jobs.get is not recommended, as you can only get the state of
jobs that are running in us-central1.
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 307 def get_job request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::GetJobRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_job..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.project_id header_params["project_id"] = request.project_id end if request.job_id header_params["job_id"] = request.job_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_job.timeout, metadata: , retry_policy: @config.rpcs.get_job.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @jobs_stub.call_rpc :get_job, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_jobs(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::Job> #list_jobs(filter: nil, project_id: nil, view: nil, page_size: nil, page_token: nil, location: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::Job>
List the jobs of a project.
To list the jobs of a project in a region, we recommend using
projects.locations.jobs.list with a regional endpoint. To
list the all jobs across all regions, use projects.jobs.aggregated. Using
projects.jobs.list is not recommended, as you can only get the list of
jobs that are running in us-central1.
527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 |
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 527 def list_jobs request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::ListJobsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_jobs..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.project_id header_params["project_id"] = request.project_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_jobs.timeout, metadata: , retry_policy: @config.rpcs.list_jobs.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @jobs_stub.call_rpc :list_jobs, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @jobs_stub, :list_jobs, request, response, operation, yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#snapshot_job(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Snapshot #snapshot_job(project_id: nil, job_id: nil, ttl: nil, location: nil, snapshot_sources: nil, description: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Snapshot
Snapshot the state of a streaming job.
808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 |
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 808 def snapshot_job request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::SnapshotJobRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.snapshot_job..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.project_id header_params["project_id"] = request.project_id end if request.job_id header_params["job_id"] = request.job_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.snapshot_job.timeout, metadata: , retry_policy: @config.rpcs.snapshot_job.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @jobs_stub.call_rpc :snapshot_job, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#update_job(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job #update_job(project_id: nil, job_id: nil, job: nil, location: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job
Updates the state of an existing Cloud Dataflow job.
To update the state of an existing job, we recommend using
projects.locations.jobs.update with a regional endpoint. Using
projects.jobs.update is not recommended, as you can only update the state
of jobs that are running in us-central1.
410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 410 def update_job request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::UpdateJobRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_job..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.project_id header_params["project_id"] = request.project_id end if request.job_id header_params["job_id"] = request.job_id end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_job.timeout, metadata: , retry_policy: @config.rpcs.update_job.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @jobs_stub.call_rpc :update_job, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |