Class: Google::Cloud::Dataflow::V1beta3::Jobs::Client

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/dataflow/v1beta3/jobs/client.rb

Overview

Client for the Jobs service.

Provides a method to create and modify Google Cloud Dataflow jobs. A Job is a multi-stage computation graph run by the Cloud Dataflow service.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new Jobs client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Dataflow::V1beta3::Jobs::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Dataflow::V1beta3::Jobs::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config) —

    Configure the Jobs client.

Yield Parameters:



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 110

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/dataflow/v1beta3/jobs_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint == Client.configure.endpoint &&
                           !@config.endpoint.split(".").first.include?("-")
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @jobs_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::Dataflow::V1beta3::JobsV1Beta3::Stub,
    credentials:  credentials,
    endpoint:     @config.endpoint,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors
  )
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the Jobs Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all Jobs clients
::Google::Cloud::Dataflow::V1beta3::Jobs::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config) —

    Configure the Client client.

Yield Parameters:

Returns:



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 55

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Dataflow", "V1beta3"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.timeout = 60.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#aggregated_list_jobs(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::Job> #aggregated_list_jobs(filter: nil, project_id: nil, view: nil, page_size: nil, page_token: nil, location: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::Job>

List the jobs of a project across all regions.

Overloads:

  • #aggregated_list_jobs(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::Job>

    Pass arguments to aggregated_list_jobs via a request object, either of type ListJobsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataflow::V1beta3::ListJobsRequest, ::Hash) —

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil) —

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #aggregated_list_jobs(filter: nil, project_id: nil, view: nil, page_size: nil, page_token: nil, location: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::Job>

    Pass arguments to aggregated_list_jobs via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • filter (::Google::Cloud::Dataflow::V1beta3::ListJobsRequest::Filter) (defaults to: nil) —

      The kind of filter to use.

    • project_id (::String) (defaults to: nil) —

      The project which owns the jobs.

    • view (::Google::Cloud::Dataflow::V1beta3::JobView) (defaults to: nil) —

      Deprecated. ListJobs always returns summaries now. Use GetJob for other JobViews.

    • page_size (::Integer) (defaults to: nil) —

      If there are many jobs, limit response to at most this many. The actual number of jobs returned will be the lesser of max_responses and an unspecified server-defined limit.

    • page_token (::String) (defaults to: nil) —

      Set this to the 'next_page_token' field of a previous response to request additional results in a long list.

    • location (::String) (defaults to: nil) —

      The regional endpoint that contains this job.

Yields:

  • (response, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error) —

    if the RPC is aborted.



510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 510

def aggregated_list_jobs request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::ListJobsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.aggregated_list_jobs..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.aggregated_list_jobs.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.aggregated_list_jobs.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @jobs_stub.call_rpc :aggregated_list_jobs, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @jobs_stub, :aggregated_list_jobs, request, response, operation, options
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#check_active_jobs(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::CheckActiveJobsResponse #check_active_jobs(project_id: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::CheckActiveJobsResponse

Check for existence of active jobs in the given project across all regions.

Overloads:

  • #check_active_jobs(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::CheckActiveJobsResponse

    Pass arguments to check_active_jobs via a request object, either of type CheckActiveJobsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataflow::V1beta3::CheckActiveJobsRequest, ::Hash) —

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil) —

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #check_active_jobs(project_id: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::CheckActiveJobsResponse

    Pass arguments to check_active_jobs via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil) —

      The project which owns the jobs.

Yields:

  • (response, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error) —

    if the RPC is aborted.



573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 573

def check_active_jobs request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::CheckActiveJobsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.check_active_jobs..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.check_active_jobs.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.check_active_jobs.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @jobs_stub.call_rpc :check_active_jobs, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#configure {|config| ... } ⇒ Client::Configuration

Configure the Jobs Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config) —

    Configure the Client client.

Yield Parameters:

Returns:



89
90
91
92
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 89

def configure
  yield @config if block_given?
  @config
end

#create_job(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job #create_job(project_id: nil, job: nil, view: nil, replace_job_id: nil, location: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job

Creates a Cloud Dataflow job.

To create a job, we recommend using projects.locations.jobs.create with a regional endpoint. Using projects.jobs.create is not recommended, as your job will always start in us-central1.

Overloads:

  • #create_job(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job

    Pass arguments to create_job via a request object, either of type CreateJobRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataflow::V1beta3::CreateJobRequest, ::Hash) —

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil) —

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_job(project_id: nil, job: nil, view: nil, replace_job_id: nil, location: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job

    Pass arguments to create_job via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil) —

      The ID of the Cloud Platform project that the job belongs to.

    • job (::Google::Cloud::Dataflow::V1beta3::Job, ::Hash) (defaults to: nil) —

      The job to create.

    • view (::Google::Cloud::Dataflow::V1beta3::JobView) (defaults to: nil) —

      The level of information requested in response.

    • replace_job_id (::String) (defaults to: nil) —

      Deprecated. This field is now in the Job message.

    • location (::String) (defaults to: nil) —

      The regional endpoint that contains this job.

Yields:

  • (response, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error) —

    if the RPC is aborted.



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 193

def create_job request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::CreateJobRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_job..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_job.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_job.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @jobs_stub.call_rpc :create_job, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_job(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job #get_job(project_id: nil, job_id: nil, view: nil, location: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job

Gets the state of the specified Cloud Dataflow job.

To get the state of a job, we recommend using projects.locations.jobs.get with a regional endpoint. Using projects.jobs.get is not recommended, as you can only get the state of jobs that are running in us-central1.

Overloads:

  • #get_job(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job

    Pass arguments to get_job via a request object, either of type GetJobRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataflow::V1beta3::GetJobRequest, ::Hash) —

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil) —

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_job(project_id: nil, job_id: nil, view: nil, location: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job

    Pass arguments to get_job via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil) —

      The ID of the Cloud Platform project that the job belongs to.

    • job_id (::String) (defaults to: nil) —

      The job ID.

    • view (::Google::Cloud::Dataflow::V1beta3::JobView) (defaults to: nil) —

      The level of information requested in response.

    • location (::String) (defaults to: nil) —

      The regional endpoint that contains this job.

Yields:

  • (response, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error) —

    if the RPC is aborted.



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 269

def get_job request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::GetJobRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_job..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_job.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_job.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @jobs_stub.call_rpc :get_job, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_jobs(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::Job> #list_jobs(filter: nil, project_id: nil, view: nil, page_size: nil, page_token: nil, location: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::Job>

List the jobs of a project.

To list the jobs of a project in a region, we recommend using projects.locations.jobs.list with a regional endpoint. To list the all jobs across all regions, use projects.jobs.aggregated. Using projects.jobs.list is not recommended, as you can only get the list of jobs that are running in us-central1.

Overloads:

  • #list_jobs(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::Job>

    Pass arguments to list_jobs via a request object, either of type ListJobsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataflow::V1beta3::ListJobsRequest, ::Hash) —

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil) —

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_jobs(filter: nil, project_id: nil, view: nil, page_size: nil, page_token: nil, location: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Dataflow::V1beta3::Job>

    Pass arguments to list_jobs via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • filter (::Google::Cloud::Dataflow::V1beta3::ListJobsRequest::Filter) (defaults to: nil) —

      The kind of filter to use.

    • project_id (::String) (defaults to: nil) —

      The project which owns the jobs.

    • view (::Google::Cloud::Dataflow::V1beta3::JobView) (defaults to: nil) —

      Deprecated. ListJobs always returns summaries now. Use GetJob for other JobViews.

    • page_size (::Integer) (defaults to: nil) —

      If there are many jobs, limit response to at most this many. The actual number of jobs returned will be the lesser of max_responses and an unspecified server-defined limit.

    • page_token (::String) (defaults to: nil) —

      Set this to the 'next_page_token' field of a previous response to request additional results in a long list.

    • location (::String) (defaults to: nil) —

      The regional endpoint that contains this job.

Yields:

  • (response, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error) —

    if the RPC is aborted.



431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 431

def list_jobs request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::ListJobsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_jobs..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_jobs.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_jobs.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @jobs_stub.call_rpc :list_jobs, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @jobs_stub, :list_jobs, request, response, operation, options
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#snapshot_job(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Snapshot #snapshot_job(project_id: nil, job_id: nil, ttl: nil, location: nil, snapshot_sources: nil, description: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Snapshot

Snapshot the state of a streaming job.

Overloads:

  • #snapshot_job(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Snapshot

    Pass arguments to snapshot_job via a request object, either of type SnapshotJobRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataflow::V1beta3::SnapshotJobRequest, ::Hash) —

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil) —

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #snapshot_job(project_id: nil, job_id: nil, ttl: nil, location: nil, snapshot_sources: nil, description: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Snapshot

    Pass arguments to snapshot_job via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil) —

      The project which owns the job to be snapshotted.

    • job_id (::String) (defaults to: nil) —

      The job to be snapshotted.

    • ttl (::Google::Protobuf::Duration, ::Hash) (defaults to: nil) —

      TTL for the snapshot.

    • location (::String) (defaults to: nil) —

      The location that contains this job.

    • snapshot_sources (::Boolean) (defaults to: nil) —

      If true, perform snapshots for sources which support this.

    • description (::String) (defaults to: nil) —

      User specified description of the snapshot. Maybe empty.

Yields:

  • (response, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error) —

    if the RPC is aborted.



645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 645

def snapshot_job request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::SnapshotJobRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.snapshot_job..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.snapshot_job.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.snapshot_job.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @jobs_stub.call_rpc :snapshot_job, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#update_job(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job #update_job(project_id: nil, job_id: nil, job: nil, location: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job

Updates the state of an existing Cloud Dataflow job.

To update the state of an existing job, we recommend using projects.locations.jobs.update with a regional endpoint. Using projects.jobs.update is not recommended, as you can only update the state of jobs that are running in us-central1.

Overloads:

  • #update_job(request, options = nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job

    Pass arguments to update_job via a request object, either of type UpdateJobRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Dataflow::V1beta3::UpdateJobRequest, ::Hash) —

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil) —

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #update_job(project_id: nil, job_id: nil, job: nil, location: nil) ⇒ ::Google::Cloud::Dataflow::V1beta3::Job

    Pass arguments to update_job via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project_id (::String) (defaults to: nil) —

      The ID of the Cloud Platform project that the job belongs to.

    • job_id (::String) (defaults to: nil) —

      The job ID.

    • job (::Google::Cloud::Dataflow::V1beta3::Job, ::Hash) (defaults to: nil) —

      The updated job. Only the job state is updatable; other fields will be ignored.

    • location (::String) (defaults to: nil) —

      The regional endpoint that contains this job.

Yields:

  • (response, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error) —

    if the RPC is aborted.



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/google/cloud/dataflow/v1beta3/jobs/client.rb', line 346

def update_job request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Dataflow::V1beta3::UpdateJobRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_job..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Dataflow::V1beta3::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_job.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_job.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @jobs_stub.call_rpc :update_job, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end