Class: Google::Cloud::Dataflow::V1beta3::Package
- Inherits:
-
Object
- Object
- Google::Cloud::Dataflow::V1beta3::Package
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/dataflow/v1beta3/environment.rb
Overview
The packages that must be installed in order for a worker to run the steps of the Cloud Dataflow job that will be assigned to its worker pool.
This is the mechanism by which the Cloud Dataflow SDK causes code to be loaded onto the workers. For example, the Cloud Dataflow Java SDK might use this to install jars containing the user's code and all of the various dependencies (libraries, data files, etc.) required in order for that code to run.
Instance Attribute Summary collapse
-
#location ⇒ ::String
The resource to read the package from.
-
#name ⇒ ::String
The name of the package.
-
#sha256 ⇒ ::String
Optional.
Instance Attribute Details
#location ⇒ ::String
Returns The resource to read the package from. The supported resource type is:
Google Cloud Storage:
storage.googleapis.com/{bucket} bucket.storage.googleapis.com/.
167 168 169 170 |
# File 'proto_docs/google/dataflow/v1beta3/environment.rb', line 167 class Package include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns The name of the package.
167 168 169 170 |
# File 'proto_docs/google/dataflow/v1beta3/environment.rb', line 167 class Package include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sha256 ⇒ ::String
Returns Optional. The hex-encoded SHA256 checksum of the package. If the checksum is provided, the worker will verify the checksum of the package before using it. If the checksum does not match, the worker will fail to start.
167 168 169 170 |
# File 'proto_docs/google/dataflow/v1beta3/environment.rb', line 167 class Package include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |