Class: Google::Cloud::Dataflow::V1beta3::RuntimeUpdatableParams
- Inherits:
-
Object
- Object
- Google::Cloud::Dataflow::V1beta3::RuntimeUpdatableParams
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/dataflow/v1beta3/jobs.rb
Overview
Additional job parameters that can only be updated during runtime using the projects.jobs.update method. These fields have no effect when specified during job creation.
Instance Attribute Summary collapse
-
#acceptable_backlog_duration ⇒ ::Google::Protobuf::Duration
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#autoscaling_tier ⇒ ::String
Optional.
-
#max_num_workers ⇒ ::Integer
The maximum number of workers to cap autoscaling at.
-
#min_num_workers ⇒ ::Integer
The minimum number of workers to scale down to.
-
#worker_utilization_hint ⇒ ::Float
Target worker utilization, compared against the aggregate utilization of the worker pool by autoscaler, to determine upscaling and downscaling when absent other constraints such as backlog.
Instance Attribute Details
#acceptable_backlog_duration ⇒ ::Google::Protobuf::Duration
This field is deprecated and may be removed in the next major version update.
Returns Optional. Deprecated: Use autoscaling_tier instead.
The backlog threshold duration in seconds for autoscaling. Value must be
non-negative.
261 262 263 264 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 261 class RuntimeUpdatableParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#autoscaling_tier ⇒ ::String
Returns Optional. The backlog threshold tier for autoscaling. Value must be one of "low-latency", "medium-latency", or "high-latency".
261 262 263 264 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 261 class RuntimeUpdatableParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_num_workers ⇒ ::Integer
Returns The maximum number of workers to cap autoscaling at. This field is currently only supported for Streaming Engine jobs.
261 262 263 264 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 261 class RuntimeUpdatableParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#min_num_workers ⇒ ::Integer
Returns The minimum number of workers to scale down to. This field is currently only supported for Streaming Engine jobs.
261 262 263 264 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 261 class RuntimeUpdatableParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#worker_utilization_hint ⇒ ::Float
Returns Target worker utilization, compared against the aggregate utilization of the worker pool by autoscaler, to determine upscaling and downscaling when absent other constraints such as backlog. For more information, see Update an existing pipeline.
261 262 263 264 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 261 class RuntimeUpdatableParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |