Class: Google::Cloud::Dataflow::V1beta3::SdkHarnessContainerImage
- Inherits:
-
Object
- Object
- Google::Cloud::Dataflow::V1beta3::SdkHarnessContainerImage
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/dataflow/v1beta3/environment.rb
Overview
Defines a SDK harness container for executing Dataflow pipelines.
Instance Attribute Summary collapse
-
#container_image ⇒ ::String
A docker container image that resides in Google Container Registry.
-
#environment_id ⇒ ::String
Environment ID for the Beam runner API proto Environment that corresponds to the current SDK Harness.
-
#use_single_core_per_container ⇒ ::Boolean
If true, recommends the Dataflow service to use only one core per SDK container instance with this image.
Instance Attribute Details
#container_image ⇒ ::String
Returns A docker container image that resides in Google Container Registry.
339 340 341 342 |
# File 'proto_docs/google/dataflow/v1beta3/environment.rb', line 339 class SdkHarnessContainerImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#environment_id ⇒ ::String
Returns Environment ID for the Beam runner API proto Environment that corresponds to the current SDK Harness.
339 340 341 342 |
# File 'proto_docs/google/dataflow/v1beta3/environment.rb', line 339 class SdkHarnessContainerImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#use_single_core_per_container ⇒ ::Boolean
Returns If true, recommends the Dataflow service to use only one core per SDK container instance with this image. If false (or unset) recommends using more than one core per SDK container instance with this image for efficiency. Note that Dataflow service may choose to override this property if needed.
339 340 341 342 |
# File 'proto_docs/google/dataflow/v1beta3/environment.rb', line 339 class SdkHarnessContainerImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |