Class: Google::Cloud::Dataflow::V1beta3::SdkVersion
- Inherits:
-
Object
- Object
- Google::Cloud::Dataflow::V1beta3::SdkVersion
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/dataflow/v1beta3/jobs.rb
Overview
The version of the SDK used to run the job.
Defined Under Namespace
Modules: SdkSupportStatus
Instance Attribute Summary collapse
-
#bugs ⇒ ::Array<::Google::Cloud::Dataflow::V1beta3::SdkBug>
readonly
Output only.
-
#sdk_support_status ⇒ ::Google::Cloud::Dataflow::V1beta3::SdkVersion::SdkSupportStatus
The support status for this SDK version.
-
#version ⇒ ::String
The version of the SDK used to run the job.
-
#version_display_name ⇒ ::String
A readable string describing the version of the SDK.
Instance Attribute Details
#bugs ⇒ ::Array<::Google::Cloud::Dataflow::V1beta3::SdkBug> (readonly)
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 360 class SdkVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The support status of the SDK used to run the job. module SdkSupportStatus # Cloud Dataflow is unaware of this version. UNKNOWN = 0 # This is a known version of an SDK, and is supported. SUPPORTED = 1 # A newer version of the SDK family exists, and an update is recommended. STALE = 2 # This version of the SDK is deprecated and will eventually be # unsupported. DEPRECATED = 3 # Support for this SDK version has ended and it should no longer be used. UNSUPPORTED = 4 end end |
#sdk_support_status ⇒ ::Google::Cloud::Dataflow::V1beta3::SdkVersion::SdkSupportStatus
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 360 class SdkVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The support status of the SDK used to run the job. module SdkSupportStatus # Cloud Dataflow is unaware of this version. UNKNOWN = 0 # This is a known version of an SDK, and is supported. SUPPORTED = 1 # A newer version of the SDK family exists, and an update is recommended. STALE = 2 # This version of the SDK is deprecated and will eventually be # unsupported. DEPRECATED = 3 # Support for this SDK version has ended and it should no longer be used. UNSUPPORTED = 4 end end |
#version ⇒ ::String
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 360 class SdkVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The support status of the SDK used to run the job. module SdkSupportStatus # Cloud Dataflow is unaware of this version. UNKNOWN = 0 # This is a known version of an SDK, and is supported. SUPPORTED = 1 # A newer version of the SDK family exists, and an update is recommended. STALE = 2 # This version of the SDK is deprecated and will eventually be # unsupported. DEPRECATED = 3 # Support for this SDK version has ended and it should no longer be used. UNSUPPORTED = 4 end end |
#version_display_name ⇒ ::String
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'proto_docs/google/dataflow/v1beta3/jobs.rb', line 360 class SdkVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The support status of the SDK used to run the job. module SdkSupportStatus # Cloud Dataflow is unaware of this version. UNKNOWN = 0 # This is a known version of an SDK, and is supported. SUPPORTED = 1 # A newer version of the SDK family exists, and an update is recommended. STALE = 2 # This version of the SDK is deprecated and will eventually be # unsupported. DEPRECATED = 3 # Support for this SDK version has ended and it should no longer be used. UNSUPPORTED = 4 end end |