Class: Google::Cloud::Dataflow::V1beta3::Straggler
- Inherits:
-
Object
- Object
- Google::Cloud::Dataflow::V1beta3::Straggler
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/dataflow/v1beta3/metrics.rb
Overview
Information for a straggler.
Instance Attribute Summary collapse
-
#batch_straggler ⇒ ::Google::Cloud::Dataflow::V1beta3::StragglerInfo
Batch straggler identification and debugging information.
-
#streaming_straggler ⇒ ::Google::Cloud::Dataflow::V1beta3::StreamingStragglerInfo
Streaming straggler identification and debugging information.
Instance Attribute Details
#batch_straggler ⇒ ::Google::Cloud::Dataflow::V1beta3::StragglerInfo
Returns Batch straggler identification and debugging information.
Note: The following fields are mutually exclusive: batch_straggler, streaming_straggler. If a field in that set is populated, all other fields in the set will automatically be cleared.
281 282 283 284 |
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 281 class Straggler include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#streaming_straggler ⇒ ::Google::Cloud::Dataflow::V1beta3::StreamingStragglerInfo
Returns Streaming straggler identification and debugging information.
Note: The following fields are mutually exclusive: streaming_straggler, batch_straggler. If a field in that set is populated, all other fields in the set will automatically be cleared.
281 282 283 284 |
# File 'proto_docs/google/dataflow/v1beta3/metrics.rb', line 281 class Straggler include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |